@@ -179,8 +179,8 @@ FolderItem *foldersel_folder_sel(Folder *cur_folder, FolderSelectionType type,
 	gtk_widget_grab_focus(treeview);
 
 	gtk_window_present(GTK_WINDOW(window));
-	gtk_window_set_modal(GTK_WINDOW(window), TRUE);
 	manage_window_set_transient(GTK_WINDOW(window));
+	gtk_window_set_modal(GTK_WINDOW(window), TRUE);
 
 	cancelled = finished = FALSE;
 
@@ -597,6 +597,11 @@ static void foldersel_new_folder(GtkButton *button, gpointer data)
 		return;
 	}
 
+	if (FOLDER_TYPE(selected_item->folder) != F_IMAP &&
+			FOLDER_TYPE(selected_item->folder) != F_NEWS &&
+			!folder_local_name_ok(new_folder))
+		return;
+
 	disp_name = trim_string(new_folder, 32);
 	AUTORELEASE_STR(disp_name, {g_free(disp_name); return;});
 
