@@ -176,7 +176,6 @@ static void set_sensitivity(GtkUIManager *ui_manager, FolderItem *item)
 static void new_folder_cb(GtkAction *action, gpointer data)
 {
 	FolderView *folderview = (FolderView *)data;
-	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
 	FolderItem *item;
 	FolderItem *new_item;
 	gchar *new_folder;
@@ -186,7 +185,7 @@ static void new_folder_cb(GtkAction *action, gpointer data)
 	
 	if (!folderview->selected) return;
 
-	item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
+	item = folderview_get_selected_item(folderview);
 	cm_return_if_fail(item != NULL);
 	cm_return_if_fail(item->folder != NULL);
 	cm_return_if_fail(item->folder->account != NULL);
@@ -349,7 +348,7 @@ static void delete_folder_cb(GtkAction *action, gpointer data)
 
 	if (!folderview->selected) return;
 
-	item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
+	item = folderview_get_selected_item(folderview);
 	cm_return_if_fail(item != NULL);
 	cm_return_if_fail(item->path != NULL);
 	cm_return_if_fail(item->folder != NULL);
@@ -492,7 +491,7 @@ static void subscribe_cb_full(FolderView *folderview, guint action)
 
 	if (!folderview->selected) return;
 
-	item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
+	item = folderview_get_selected_item(folderview);
 	cm_return_if_fail(item != NULL);
 	cm_return_if_fail(item->folder != NULL);
 
@@ -513,8 +512,8 @@ static void subscribe_cb_full(FolderView *folderview, guint action)
 				G_CALLBACK(chk_update_val), &recurse);
 
 		avalue = alertpanel_full(_("Subscriptions"), message,
-		 			 GTK_STOCK_CANCEL, _("+_Search"), NULL, FALSE,
-					 rec_chk, ALERT_QUESTION, G_ALERTDEFAULT);
+		 			 GTK_STOCK_CANCEL, g_strconcat("+", _("_Search"), NULL),
+					 NULL, FALSE, rec_chk, ALERT_QUESTION, G_ALERTDEFAULT);
 		g_free(message);
 		if (avalue != G_ALERTALTERNATE) return;
 		
@@ -572,7 +571,8 @@ static void subscribe_cb_full(FolderView *folderview, guint action)
 			G_CALLBACK(chk_update_val), &recurse);
 
 	avalue = alertpanel_full(_("Subscriptions"), message,
-		 		 GTK_STOCK_CANCEL, action?_("+_Subscribe"):_("+_Unsubscribe"), NULL, FALSE,
+		 		 GTK_STOCK_CANCEL, action?g_strconcat("+", _("_Subscribe"), NULL):
+		 		 g_strconcat("+", _("_Unsubscribe"), NULL), NULL, FALSE,
 				 rec_chk, ALERT_QUESTION, G_ALERTDEFAULT);
 	g_free(message);
 	if (avalue != G_ALERTALTERNATE) return;
@@ -613,7 +613,7 @@ static void subscribed_cb(GtkAction *action, gpointer data)
 {
 	FolderView *folderview = (FolderView *)data;
 	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
-	FolderItem *item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
+	FolderItem *item = folderview_get_selected_item(folderview);
 	
 	if (!item || !item->folder || !item->folder->account)
 		return;
@@ -635,11 +635,10 @@ static void subscribed_cb(GtkAction *action, gpointer data)
 static void download_cb(GtkAction *action, gpointer data)
 {
 	FolderView *folderview = (FolderView *)data;
-	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
 	FolderItem *item;
 
 	if (!folderview->selected) return;
 
-	item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
+	item = folderview_get_selected_item(folderview);
 	imap_gtk_synchronise(item, 0);
 }
