@@ -536,7 +536,7 @@ void bsfilter_save_config(void)
 		return;
 
 	if (prefs_write_param(param, pfile->fp) < 0) {
-		g_warning("Failed to write Bsfilter configuration to file\n");
+		g_warning("Failed to write Bsfilter configuration to file");
 		prefs_file_close_revert(pfile);
 		return;
 	}
