@@ -1,20 +1,22 @@
 /*
  * Claws Mail -- A GTK+ based, lightweight, and fast e-mail client
  * == Fancy Plugin ==
- * Copyright(C) 1999-2014 the Claws Mail Team
+ * Copyright(C) 1999-2015 the Claws Mail Team
  * This file Copyright (C) 2009-2014 Salvatore De Paolis
  * <iwkse@claws-mail.org> and the Claws Mail Team
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write tothe Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -420,7 +422,7 @@ static void resource_request_starting_cb(WebKitWebView		*view,
 				}
 				if ((err = procmime_get_part(filename, partinfo)) < 0)
 					alertpanel_error(_("Couldn't save the part of multipart message: %s"),
-										strerror(-err));
+										g_strerror(-err));
 				gchar *file_uri = g_filename_to_uri(filename, NULL, NULL);
 				webkit_network_request_set_uri(request, file_uri);
 				g_free(file_uri);
