@@ -127,6 +127,15 @@ gboolean rssyl_subscribe(FolderItem *parent, const gchar *url,
 	/* Create a folder for it. */
 	tmpname = rssyl_format_string(ctx->feed->title, TRUE, TRUE);
 	tmpname2 = g_strdup(tmpname);
+
+#ifdef G_OS_WIN32
+	/* Windows does not allow its filenames to start or end with a dot. */
+	if (tmpname2[0] == '.')
+		tmpname2[0] = "_";
+	if (tmpname2[strlen(tmpname2) - 1] == '.')
+		tmpname2[strlen(tmpname2) - 1] == '_';
+#endif
+
 	while (folder_find_child_item_by_name(parent, tmpname2) != 0 && i < 20) {
 		debug_print("RSSyl: Folder '%s' already exists, trying another name\n",
 				tmpname2);
