@@ -674,20 +674,21 @@ static void build_day_view_colours(day_win *dw)
     gdk_colormap_alloc_color(pic1_cmap, &dw->bg2, FALSE, TRUE);
 
     if (!gdk_color_parse("white", &dw->line_color)) {
+        g_warning("color parse failed: white");
         dw->line_color.red =  239 * (65535/255);
         dw->line_color.green = 235 * (65535/255);
         dw->line_color.blue = 230 * (65535/255);
     }
 
     if (!gdk_color_parse("blue", &dw->fg_sunday)) {
-        g_warning("color parse failed: red\n");
+        g_warning("color parse failed: blue");
         dw->fg_sunday.red = 10 * (65535/255);
         dw->fg_sunday.green = 10 * (65535/255);
         dw->fg_sunday.blue = 255 * (65535/255);
     }
 
     if (!gdk_color_parse("gold", &dw->bg_today)) {
-        g_warning("color parse failed: gold\n");
+        g_warning("color parse failed: gold");
         dw->bg_today.red = 255 * (65535/255);
         dw->bg_today.green = 215 * (65535/255);
         dw->bg_today.blue = 115 * (65535/255);
