@@ -1161,7 +1161,8 @@ static void vcal_set_mtime(Folder *folder, FolderItem *item)
 	}
 
 	item->mtime = s.st_mtime;
-	debug_print("VCAL: forced mtime of %s to %ld\n", item->name?item->name:"(null)", item->mtime);
+	debug_print("VCAL: forced mtime of %s to %lld\n",
+			item->name?item->name:"(null)", (long long)item->mtime);
 	g_free(path);
 }
 
@@ -1958,7 +1959,7 @@ static void unsubscribe_cal_cb(GtkAction *action, gpointer data)
 
 	if (!folderview->selected) return;
 
-	item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
+	item = folderview_get_selected_item(folderview);
 	g_return_if_fail(item != NULL);
 	g_return_if_fail(item->path != NULL);
 	g_return_if_fail(item->folder != NULL);
@@ -2065,14 +2066,13 @@ static void set_view_cb(GtkAction *gaction, GtkRadioAction *current, gpointer da
 {
 	FolderView *folderview = (FolderView *)data;
 	gint action = gtk_radio_action_get_current_value (GTK_RADIO_ACTION (current));
-	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
 	FolderItem *item = NULL, *oitem = NULL;
 
 	if (!folderview->selected) return;
 	if (setting_sensitivity) return;
 
-	oitem = gtk_cmctree_node_get_row_data(ctree, folderview->opened);
-	item = gtk_cmctree_node_get_row_data(ctree, folderview->selected);
+	oitem = folderview_get_opened_item(folderview);
+	item = folderview_get_selected_item(folderview);
 
 	if (!item)
 		return;
