@@ -398,7 +398,7 @@ static void prefs_custom_header_write_config(PrefsAccount *ac)
 	}
 
 	if ((pfile = prefs_write_open(rcpath)) == NULL) {
-		g_warning("failed to write configuration to file\n");
+		g_warning("failed to write configuration to file");
 		g_free(rcpath);
 		return;
 	}
@@ -444,7 +444,7 @@ static void prefs_custom_header_write_config(PrefsAccount *ac)
  	}
 
 	if (prefs_file_close(pfile) < 0) {
-		g_warning("failed to write configuration to file\n");
+		g_warning("failed to write configuration to file");
 		return;
 	}
 }
