@@ -75,12 +75,10 @@ struct _FolderItemGeneralPage
 	GtkWidget *table;
 	GtkWidget *no_save_warning;
 	GtkWidget *folder_type;
-#ifndef G_OS_WIN32
 	GtkWidget *checkbtn_simplify_subject;
 	GtkWidget *entry_simplify_subject;
 	GtkWidget *entry_regexp_test_string;
 	GtkWidget *entry_regexp_test_result;
-#endif
 	GtkWidget *checkbtn_folder_chmod;
 	GtkWidget *entry_folder_chmod;
 	GtkWidget *folder_color_btn;
@@ -95,9 +93,7 @@ struct _FolderItemGeneralPage
 	GtkWidget *promote_html_part;
 	
 	/* apply to sub folders */
-#ifndef G_OS_WIN32
 	GtkWidget *simplify_subject_rec_checkbtn;
-#endif
 	GtkWidget *folder_chmod_rec_checkbtn;
 	GtkWidget *folder_color_rec_checkbtn;
 	GtkWidget *enable_processing_rec_checkbtn;
@@ -194,10 +190,9 @@ static gint prefs_folder_item_chmod_mode		(gchar *folder_chmod);
 
 static void folder_color_set_dialog(GtkWidget *widget, gpointer data);
 static void clean_cache_cb(GtkWidget *widget, gpointer data);
-#ifndef G_OS_WIN32
 static void folder_regexp_test_cb(GtkWidget *widget, gpointer data);
 static void folder_regexp_set_subject_example_cb(GtkWidget *widget, gpointer data);
-#endif
+
 #define SAFE_STRING(str) \
 	(str) ? (str) : ""
 
@@ -220,14 +215,14 @@ static void prefs_folder_item_general_create_widget_func(PrefsPage * page_,
 	SpecialFolderItemType type;
 	
 	GtkWidget *no_save_warning = NULL;
-#ifndef G_OS_WIN32
+
 	GtkWidget *checkbtn_simplify_subject;
 	GtkWidget *entry_simplify_subject;
 	GtkWidget *label_regexp_test;
 	GtkWidget *entry_regexp_test_string;
 	GtkWidget *label_regexp_result;
 	GtkWidget *entry_regexp_test_result;
-#endif
+
 	GtkWidget *checkbtn_folder_chmod;
 	GtkWidget *entry_folder_chmod;
 	GtkWidget *folder_color;
@@ -243,9 +238,8 @@ static void prefs_folder_item_general_create_widget_func(PrefsPage * page_,
 	GtkWidget *promote_html_part;
 	GtkListStore *promote_html_part_menu;
 
-#ifndef G_OS_WIN32
 	GtkWidget *simplify_subject_rec_checkbtn;
-#endif
+
 	GtkWidget *folder_chmod_rec_checkbtn;
 	GtkWidget *folder_color_rec_checkbtn;
 	GtkWidget *enable_processing_rec_checkbtn;
@@ -264,10 +258,10 @@ static void prefs_folder_item_general_create_widget_func(PrefsPage * page_,
 	rowcount = 0;
 
 	if (!can_save) {
-		no_save_warning = gtk_label_new(
-			_("<i>These preferences will not be saved as this folder "
+		no_save_warning = gtk_label_new(g_strconcat("<i>",
+			_("These preferences will not be saved as this folder "
 			"is a top-level folder. However, you can set them for the "
-			"whole mailbox tree by using \"Apply to subfolders\".</i>"));
+			"whole mailbox tree by using \"Apply to subfolders\"."), "</i>", NULL));
 		gtk_label_set_use_markup(GTK_LABEL(no_save_warning), TRUE);
 		gtk_label_set_line_wrap(GTK_LABEL(no_save_warning), TRUE);
 		gtk_misc_set_alignment(GTK_MISC(no_save_warning), 0.0, 0.5);
@@ -331,7 +325,6 @@ static void prefs_folder_item_general_create_widget_func(PrefsPage * page_,
 
 	rowcount++;
 
-#ifndef G_OS_WIN32
 	/* Simplify Subject */
 	checkbtn_simplify_subject = gtk_check_button_new_with_label(_("Simplify Subject RegExp"));
 	gtk_table_attach(GTK_TABLE(table), checkbtn_simplify_subject, 0, 1, 
@@ -389,7 +382,7 @@ static void prefs_folder_item_general_create_widget_func(PrefsPage * page_,
 	gtk_editable_set_editable(GTK_EDITABLE(entry_regexp_test_result), FALSE);
 
 	rowcount++;
-#endif
+
 	/* Folder chmod */
 	checkbtn_folder_chmod = gtk_check_button_new_with_label(_("Folder chmod"));
 	gtk_table_attach(GTK_TABLE(table), checkbtn_folder_chmod, 0, 1, 
@@ -615,12 +608,12 @@ static void prefs_folder_item_general_create_widget_func(PrefsPage * page_,
 	page->table = table;
 	page->folder_type = folder_type;
 	page->no_save_warning = no_save_warning;
-#ifndef G_OS_WIN32
+
 	page->checkbtn_simplify_subject = checkbtn_simplify_subject;
 	page->entry_simplify_subject = entry_simplify_subject;
 	page->entry_regexp_test_string = entry_regexp_test_string;
 	page->entry_regexp_test_result = entry_regexp_test_result;
-#endif
+
 	page->checkbtn_folder_chmod = checkbtn_folder_chmod;
 	page->entry_folder_chmod = entry_folder_chmod;
 	page->folder_color_btn = folder_color_btn;
@@ -634,9 +627,9 @@ static void prefs_folder_item_general_create_widget_func(PrefsPage * page_,
 	page->checkbtn_remove_old_offlinesync = checkbtn_remove_old_offlinesync;
 	page->promote_html_part = promote_html_part;
 
-#ifndef G_OS_WIN32
+
 	page->simplify_subject_rec_checkbtn  = simplify_subject_rec_checkbtn;
-#endif
+
 	page->folder_chmod_rec_checkbtn	     = folder_chmod_rec_checkbtn;
 	page->folder_color_rec_checkbtn	     = folder_color_rec_checkbtn;
 	page->enable_processing_rec_checkbtn = enable_processing_rec_checkbtn;
@@ -647,9 +640,7 @@ static void prefs_folder_item_general_create_widget_func(PrefsPage * page_,
 
 	page->page.widget = table;
 
-#ifndef G_OS_WIN32
 	folder_regexp_set_subject_example_cb(NULL, page);
-#endif
 }
 
 static void prefs_folder_item_general_destroy_widget_func(PrefsPage *page_) 
@@ -690,7 +681,6 @@ static void general_save_folder_prefs(FolderItem *folder, FolderItemGeneralPage
 	if (all || gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(page->promote_html_part_rec_checkbtn)))
 		prefs->promote_html_part = promote_html_part;
 
-#ifndef G_OS_WIN32
 	if (all || gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(page->simplify_subject_rec_checkbtn))) {
 		gboolean old_simplify_subject = prefs->enable_simplify_subject;
 		int regexp_diffs = strcmp2(prefs->simplify_subject_regexp, gtk_editable_get_chars(
@@ -702,7 +692,7 @@ static void general_save_folder_prefs(FolderItem *folder, FolderItemGeneralPage
 		if (old_simplify_subject != prefs->enable_simplify_subject || regexp_diffs != 0)
 			summary_update_needed = TRUE;
 	}
-#endif	
+
 	if (all || gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(page->folder_chmod_rec_checkbtn))) {
 		prefs->enable_folder_chmod = 
 			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(page->checkbtn_folder_chmod));
@@ -767,9 +757,7 @@ static gboolean general_save_recurse_func(GNode *node, gpointer data)
 	   it once */
 	if ((node == page->item->node) &&
 	    !(
-#ifndef G_OS_WIN32
 	      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(page->simplify_subject_rec_checkbtn)) ||
-#endif
 	      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(page->folder_chmod_rec_checkbtn)) ||
 	      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(page->folder_color_rec_checkbtn)) ||
 	      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(page->enable_processing_rec_checkbtn)) ||
@@ -872,10 +860,10 @@ static void prefs_folder_item_compose_create_widget_func(PrefsPage * page_,
 	rowcount = 0;
 
 	if (!can_save) {
-		no_save_warning = gtk_label_new(
-			_("<i>These preferences will not be saved as this folder "
+		no_save_warning = gtk_label_new(g_strconcat("<i>",
+			_("These preferences will not be saved as this folder "
 			"is a top-level folder. However, you can set them for the "
-			"whole mailbox tree by using \"Apply to subfolders\".</i>"));
+			"whole mailbox tree by using \"Apply to subfolders\"."), "</i>", NULL));
 		gtk_label_set_use_markup(GTK_LABEL(no_save_warning), TRUE);
 		gtk_label_set_line_wrap(GTK_LABEL(no_save_warning), TRUE);
 		gtk_misc_set_alignment(GTK_MISC(no_save_warning), 0.0, 0.5);
@@ -1398,10 +1386,10 @@ static void prefs_folder_item_templates_create_widget_func(PrefsPage * page_,
 	gtk_widget_show (page_vbox);
 	
 	if (!can_save) {
-		no_save_warning = gtk_label_new(
-			_("<i>These preferences will not be saved as this folder "
+		no_save_warning = gtk_label_new(g_strconcat("<i>",
+			_("These preferences will not be saved as this folder "
 			"is a top-level folder. However, you can set them for the "
-			"whole mailbox tree by using \"Apply to subfolders\".</i>"));
+			"whole mailbox tree by using \"Apply to subfolders\"."), "</i>", NULL));
 		gtk_label_set_use_markup(GTK_LABEL(no_save_warning), TRUE);
 		gtk_label_set_line_wrap(GTK_LABEL(no_save_warning), TRUE);
 		gtk_misc_set_alignment(GTK_MISC(no_save_warning), 0.0, 0.5);
@@ -1684,8 +1672,8 @@ static void clean_cache_cb(GtkWidget *widget, gpointer data)
 	if (alertpanel_full(_("Discard cache"), 
 			    _("Do you really want to discard the local cached "
 			      "data for this folder?"),
-		 		 GTK_STOCK_CANCEL, _("+Discard"), NULL, FALSE,
-				 NULL, ALERT_WARNING, G_ALERTDEFAULT)
+		 		 GTK_STOCK_CANCEL, g_strconcat("+", _("Discard"), NULL),
+				 NULL, FALSE, NULL, ALERT_WARNING, G_ALERTDEFAULT)
 		!= G_ALERTALTERNATE)
 		return;
 	
@@ -1701,7 +1689,6 @@ static void clean_cache_cb(GtkWidget *widget, gpointer data)
 		folderview_select(folderview,item);
 }
 
-#ifndef G_OS_WIN32
 static regex_t *summary_compile_simplify_regexp(gchar *simplify_subject_regexp)
 {
 	int err;
@@ -1807,7 +1794,7 @@ static void folder_regexp_set_subject_example_cb(GtkWidget *widget, gpointer dat
 		}
 	}
 }
-#endif
+
 static void register_general_page()
 {
 	static gchar *pfi_general_path[2];
