@@ -80,7 +80,7 @@ void prefs_read_config(PrefParam *param, const gchar *label,
 	cm_return_if_fail(rcfile != NULL);
 
 	if (encoding != NULL)
-		g_warning("Encoding is ignored\n");
+		g_warning("Encoding is ignored");
 
 	debug_print("Reading configuration...\n");
 
@@ -242,7 +242,7 @@ static void prefs_config_parse_one_line(PrefParam *param, const gchar *buf)
 #define TRY(func) \
 if (!(func)) \
 { \
-	g_warning("Failed to write configuration to file\n"); \
+	g_warning("Failed to write configuration to file"); \
 	if (orig_fp) fclose(orig_fp); \
 	prefs_file_close_revert(pfile); \
 	g_free(rcpath); \
@@ -270,7 +270,7 @@ void prefs_write_config(PrefParam *param, const gchar *label,
 	}
 
 	if ((pfile = prefs_write_open(rcpath)) == NULL) {
-		g_warning("Failed to write configuration to file\n");
+		g_warning("Failed to write configuration to file");
 		if (orig_fp) fclose(orig_fp);
 		g_free(rcpath);
 		return;
@@ -326,7 +326,7 @@ void prefs_write_config(PrefParam *param, const gchar *label,
 
 	if (orig_fp) fclose(orig_fp);
 	if (prefs_file_close(pfile) < 0)
-		g_warning("Failed to write configuration to file\n");
+		g_warning("Failed to write configuration to file");
 	g_free(rcpath);
 
 	debug_print("Configuration is saved.\n");
@@ -674,7 +674,7 @@ void prefs_set_data_from_entry(PrefParam *pparam)
 		*((gint *)pparam->data) = atoi(entry_str);
 		break;
 	default:
-		g_warning("Invalid PrefType for GtkEntry widget: %d\n",
+		g_warning("Invalid PrefType for GtkEntry widget: %d",
 			  pparam->type);
 	}
 }
@@ -692,7 +692,7 @@ void prefs_set_escaped_data_from_entry(PrefParam *pparam)
 		*str = pref_get_pref_from_entry(GTK_ENTRY(*pparam->widget));
 		break;
 	default:
-		g_warning("Invalid escaped PrefType for GtkEntry widget: %d\n",
+		g_warning("Invalid escaped PrefType for GtkEntry widget: %d",
 			  pparam->type);
 	}
 }
@@ -719,7 +719,7 @@ void prefs_set_entry(PrefParam *pparam)
 				   itos(*((gushort *)pparam->data)));
 		break;
 	default:
-		g_warning("Invalid PrefType for GtkEntry widget: %d\n",
+		g_warning("Invalid PrefType for GtkEntry widget: %d",
 			  pparam->type);
 	}
 }
@@ -737,7 +737,7 @@ void prefs_set_entry_from_escaped(PrefParam *pparam)
 				   *str ? *str : "");
 		break;
 	default:
-		g_warning("Invalid escaped PrefType for GtkEntry widget: %d\n",
+		g_warning("Invalid escaped PrefType for GtkEntry widget: %d",
 			  pparam->type);
 	}
 }
@@ -790,7 +790,7 @@ void prefs_set_data_from_text(PrefParam *pparam)
 		g_free(text);
 		break;
 	default:
-		g_warning("Invalid PrefType for GtkText widget: %d\n",
+		g_warning("Invalid PrefType for GtkText widget: %d",
 			  pparam->type);
 	}
 }
@@ -808,7 +808,7 @@ void prefs_set_escaped_data_from_text(PrefParam *pparam)
 		*str = pref_get_pref_from_textview(GTK_TEXT_VIEW(*pparam->widget));
 		break;
 	default:
-		g_warning("Invalid escaped PrefType for GtkText widget: %d\n",
+		g_warning("Invalid escaped PrefType for GtkText widget: %d",
 			  pparam->type);
 	}
 }
@@ -851,7 +851,7 @@ void prefs_set_text(PrefParam *pparam)
 		gtk_text_buffer_insert(buffer, &iter, buf, -1);
 		break;
 	default:
-		g_warning("Invalid PrefType for GtkTextView widget: %d\n",
+		g_warning("Invalid PrefType for GtkTextView widget: %d",
 			  pparam->type);
 	}
 }
@@ -869,7 +869,7 @@ void prefs_set_text_from_escaped(PrefParam *pparam)
 				 *str ? *str : "");
 		break;
 	default:
-		g_warning("Invalid escaped PrefType for GtkTextView widget: %d\n",
+		g_warning("Invalid escaped PrefType for GtkTextView widget: %d",
 			  pparam->type);
 	}
 }
@@ -908,7 +908,7 @@ void prefs_set_data_from_spinbtn(PrefParam *pparam)
 			(GTK_SPIN_BUTTON(*pparam->widget));
 		break;
 	default:
-		g_warning("Invalid PrefType for GtkSpinButton widget: %d\n",
+		g_warning("Invalid PrefType for GtkSpinButton widget: %d",
 			  pparam->type);
 	}
 }
@@ -927,18 +927,27 @@ void prefs_set_spinbtn(PrefParam *pparam)
 					  (gfloat)*((gushort *)pparam->data));
 		break;
 	default:
-		g_warning("Invalid PrefType for GtkSpinButton widget: %d\n",
+		g_warning("Invalid PrefType for GtkSpinButton widget: %d",
 			  pparam->type);
 	}
 }
 
 static GSList *prefs_pages = NULL;
 
+static void prefs_gtk_window_closed_cb(PrefsWindow *prefswindow)
+{
+	if (prefswindow == NULL)
+		return;
+
+	if (prefswindow->dialog_response > PREFSWINDOW_RESPONSE_CANCEL)
+		prefs_common_write_config();
+}
+
 void prefs_gtk_open(void)
 {
 	prefswindow_open(_("Preferences"), prefs_pages, NULL,
 			&prefs_common.prefswin_width, &prefs_common.prefswin_height,
-			NULL, NULL);
+			NULL, prefs_gtk_window_closed_cb, prefs_gtk_window_closed_cb);
 }
 
 void prefs_gtk_register_page(PrefsPage *page)
@@ -1095,7 +1104,7 @@ static gboolean prefs_read_config_from_cache(PrefParam *param, const gchar *labe
 	sections_table = g_hash_table_lookup(whole_cache, rcfile);
 	
 	if (sections_table == NULL) {
-		g_warning("Can't find %s in the whole cache\n", rcfile?rcfile:"(null)");
+		g_warning("Can't find %s in the whole cache", rcfile?rcfile:"(null)");
 		return FALSE;
 	}
 	values_table = g_hash_table_lookup(sections_table, label);
